****************************
API documentation: iqm-pulse
****************************

:Version: |release|
:Date: |today|

This is the documentation of the IQM pulse library.


Contents
========

.. toctree::
   :maxdepth: 2

   API

.. toctree::
   :maxdepth: 1

   Changelog <changelog>
   references
   License <license>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
